@@ -10,12 +10,17 @@ class PeachTest < Test::Unit::TestCase
       normal_f = f.to_s[1..-1].to_sym
 
       setup do
-        @data = [1, 2, 3, 5, 8]
+        @data = [1, 2, 3, 5, 8]*1001
         @block = lambda{|i| i**2}
       end
       should "return the same result as #{normal_f}" do
         assert_equal @data.send(normal_f, &@block),
-          @data.send(f, nil, &@block)
+          @data.send(f, 100, &@block)
+      end
+
+      should "return the same result as #{normal_f} for empty list" do
+        assert_equal [].send(normal_f, &@block),
+          [].send(f, nil, &@block)
       end
     end
   end
@@ -38,39 +43,4 @@ class PeachTest < Test::Unit::TestCase
     end
   end
 
-  context "divvy" do
-    setup do
-      @data = [1, 2, 3, 4, 5]
-    end
-
-    context "on empty list" do
-      should "return empty list" do
-        assert_equal [], [].send(:peach_divvy)
-      end
-    end
-
-    context "when n is nil" do
-      should "put 1 element into each division" do
-        assert_equal @data.size, @data.send(:peach_divvy).size
-      end
-    end
-
-    context "when n is less than array size" do
-      should "put create n divisions" do
-        assert_equal 2, @data.send(:peach_divvy, 2).size
-      end
-
-      should "not lose any array elements" do
-        assert_equal @data.size, @data.send(:peach_divvy, 2).inject(0) {|sum, i|
-          sum + i.size
-        }
-      end
-    end
-
-    context "when n is greater than array size" do
-      should "only create 'array size' divisions" do
-        assert_equal @data.size, @data.send(:peach_divvy, 42).size
-      end
-    end
-  end
 end
